@@ -31,7 +31,7 @@ public:
 protected:
     virtual void keyPressEvent(QKeyEvent *e)
     {
-        if (e->text() == "q")
+        if (e->text() == QLatin1String( "q" ))
         {
             kapp->quit();
         }
